==> sdk_services-3.0.2-sources.jar: ir/map/sdk_services/models/Leg.java <==

package ir.map.sdk_services.models;

import com.google.gson.annotations.Expose;
import com.google.gson.annotations.SerializedName;

import java.util.List;

public class Leg {

    @SerializedName("startTime")
    @Expose
    public Long startTime;
    @SerializedName("endTime")
    @Expose
    public Long endTime;
    @SerializedName("departureDelay")
    @Expose
    public Long departureDelay;
    @SerializedName("arrivalDelay")
    @Expose
    public Long arrivalDelay;
    @SerializedName("realTime")
    @Expose
    public Boolean realTime;
    @SerializedName("distance")
    @Expose
    public Double distance;
    @SerializedName("pathway")
    @Expose
    public Boolean pathway;
    @SerializedName("mode")
    @Expose
    public String mode;
    @SerializedName("route")
    @Expose
    public String route;
    @SerializedName("agencyTimeZoneOffset")
    @Expose
    public Long agencyTimeZoneOffset;
    @SerializedName("interlineWithPreviousLeg")
    @Expose
    public Boolean interlineWithPreviousLeg;
    @SerializedName("from")
    @Expose
    public From from;
    @SerializedName("to")
    @Expose
    public To to;
    @SerializedName("maptexLegGeometry")
    @Expose
    public MaptexLegGeometry maptexLegGeometry;
    @SerializedName("rentedBike")
    @Expose
    public Boolean rentedBike;
    @SerializedName("transitLeg")
    @Expose
    public Boolean transitLeg;
    @SerializedName("duration")
    @Expose
    public Long duration;
    @SerializedName("steps")
    @Expose
    public List<Step> steps = null;
    @SerializedName("agencyName")
    @Expose
    public String agencyName;
    @SerializedName("agencyUrl")
    @Expose
    public String agencyUrl;
    @SerializedName("routeType")
    @Expose
    public Integer routeType;
    @SerializedName("routeId")
    @Expose
    public String routeId;
    @SerializedName("tripShortName")
    @Expose
    public String tripShortName;
    @SerializedName("headsign")
    @Expose
    public String headsign;
    @SerializedName("agencyId")
    @Expose
    public String agencyId;
    @SerializedName("tripId")
    @Expose
    public String tripId;
    @SerializedName("serviceDate")
    @Expose
    public String serviceDate;
    @SerializedName("routeShortName")
    @Expose
    public String routeShortName;
    @SerializedName("routeLongName")
    @Expose
    public String routeLongName;

}

==> sdk_services-3.0.5-sources.jar: ir/map/sdk_services/models/Leg.java <==

package ir.map.sdk_services.models;

import com.google.gson.annotations.Expose;
import com.google.gson.annotations.SerializedName;

import java.util.List;

public class Leg {

    @SerializedName("startTime")
    @Expose
    public Long startTime;
    @SerializedName("endTime")
    @Expose
    public Long endTime;
    @SerializedName("departureDelay")
    @Expose
    public Long departureDelay;
    @SerializedName("arrivalDelay")
    @Expose
    public Long arrivalDelay;
    @SerializedName("realTime")
    @Expose
    public Boolean realTime;
    @SerializedName("distance")
    @Expose
    public Double distance;
    @SerializedName("pathway")
    @Expose
    public Boolean pathway;
    @SerializedName("mode")
    @Expose
    public String mode;
    @SerializedName("route")
    @Expose
    public String route;
    @SerializedName("agencyTimeZoneOffset")
    @Expose
    public Long agencyTimeZoneOffset;
    @SerializedName("interlineWithPreviousLeg")
    @Expose
    public Boolean interlineWithPreviousLeg;
    @SerializedName("from")
    @Expose
    public From from;
    @SerializedName("to")
    @Expose
    public To to;
  @SerializedName("legGeometry")
    @Expose
  public MapirLegGeometry mapirLegGeometry;
    @SerializedName("rentedBike")
    @Expose
    public Boolean rentedBike;
    @SerializedName("transitLeg")
    @Expose
    public Boolean transitLeg;
    @SerializedName("duration")
    @Expose
    public Long duration;
    @SerializedName("steps")
    @Expose
    public List<Step> steps = null;
    @SerializedName("agencyName")
    @Expose
    public String agencyName;
    @SerializedName("agencyUrl")
    @Expose
    public String agencyUrl;
    @SerializedName("routeType")
    @Expose
    public Integer routeType;
    @SerializedName("routeId")
    @Expose
    public String routeId;
    @SerializedName("tripShortName")
    @Expose
    public String tripShortName;
    @SerializedName("headsign")
    @Expose
    public String headsign;
    @SerializedName("agencyId")
    @Expose
    public String agencyId;
    @SerializedName("tripId")
    @Expose
    public String tripId;
    @SerializedName("serviceDate")
    @Expose
    public String serviceDate;
    @SerializedName("routeShortName")
    @Expose
    public String routeShortName;
    @SerializedName("routeLongName")
    @Expose
    public String routeLongName;

}
